@@ -16,6 +16,7 @@ class StaticPath:
     divider = resource_root / "b30" / "Divider.png"
     mask = resource_root / "b30" / "mask.png"
     table = resource_root / "b30" / "table.png"
+    ptt = resource_root / "b30" / "Ptt.png"
     char_dir = assets_root / "char"
     song_dir = assets_root / "song"
     ptt_dir = resource_root / "ptt"
@@ -31,6 +32,7 @@ class StaticPath:
     kazesawa_regular = resource_root / "font" / "Kazesawa-Regular.ttf"
     exo_semibold = resource_root / "font" / "Exo-SemiBold.ttf"
     exo_regular = resource_root / "font" / "Exo-Regular.ttf"
+    nsc_regular = resource_root / "font" / "NotoSansCJK-Regular.otf"
     # Help
     help = resource_root / "help.png"
 
@@ -39,24 +41,5 @@ class StaticPath:
         return path.join(str(assets_root), *args)
 
     @staticmethod
-    def is_failed(character: int, health: int, score: int, lost_count: int):
-        def _check(x, y):
-            return (
-                x not in [7, 10, 14, 15, 28, 29, 35, 36, 37, 41, 42, 43] and y < 70
-            ) or (y == -1)
-
-        return (
-            StaticPath.track_failed
-            if _check(character, health)
-            else track_complete(score, lost_count)
-        )
-
-
-def track_complete(score: int, lost_count: int) -> str:
-    if not lost_count:
-        return (
-            resource_root / "recent" / "clear_pure.png"
-            if score > int(1e7)
-            else resource_root / "recent" / "clear_full.png"
-        )
-    return resource_root / "recent" / "clear_normal.png"
+    def is_failed(type: str):
+        return resource_root / "recent" / f"{type}.png"
